Class: Google::Cloud::RecaptchaEnterprise::V1::AccountDefenderAssessment
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::AccountDefenderAssessment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Account defender risk assessment.
Defined Under Namespace
Modules: AccountDefenderLabel
Instance Attribute Summary collapse
-
#labels ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::AccountDefenderAssessment::AccountDefenderLabel>
readonly
Output only.
Instance Attribute Details
#labels ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::AccountDefenderAssessment::AccountDefenderLabel> (readonly)
Returns Output only. Labels for this request.
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1127 class AccountDefenderAssessment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Labels returned by account defender for this request. # Ensure that applications can handle values not explicitly listed. module AccountDefenderLabel # Default unspecified type. ACCOUNT_DEFENDER_LABEL_UNSPECIFIED = 0 # The request matches a known good profile for the user. PROFILE_MATCH = 1 # The request is potentially a suspicious login event and must be further # verified either through multi-factor authentication or another system. SUSPICIOUS_LOGIN_ACTIVITY = 2 # The request matched a profile that previously had suspicious account # creation behavior. This can mean that this is a fake account. SUSPICIOUS_ACCOUNT_CREATION = 3 # The account in the request has a high number of related accounts. It does # not necessarily imply that the account is bad but can require further # investigation. RELATED_ACCOUNTS_NUMBER_HIGH = 4 end end |