Class: Google::Cloud::RecaptchaEnterprise::V1::AndroidKeySettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Settings specific to keys that can be used by Android apps.

Instance Attribute Summary collapse

Instance Attribute Details

#allow_all_package_names::Boolean

Returns Optional. If set to true, allowed_package_names are not enforced.

Returns:

  • (::Boolean)

    Optional. If set to true, allowed_package_names are not enforced.



1626
1627
1628
1629
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1626

class AndroidKeySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#allowed_package_names::Array<::String>

Returns Optional. Android package names of apps allowed to use the key. Example: 'com.companyname.appname' Each key supports a maximum of 250 package names. To use a key on more apps, set allow_all_package_names to true. When this is set, you are responsible for validating the package name by checking the token_properties.android_package_name field in each assessment response against your list of allowed package names.

Returns:

  • (::Array<::String>)

    Optional. Android package names of apps allowed to use the key. Example: 'com.companyname.appname' Each key supports a maximum of 250 package names. To use a key on more apps, set allow_all_package_names to true. When this is set, you are responsible for validating the package name by checking the token_properties.android_package_name field in each assessment response against your list of allowed package names.



1626
1627
1628
1629
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1626

class AndroidKeySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#support_non_google_app_store_distribution::Boolean

Returns Optional. Set to true for keys that are used in an Android application that is available for download in app stores in addition to the Google Play Store.

Returns:

  • (::Boolean)

    Optional. Set to true for keys that are used in an Android application that is available for download in app stores in addition to the Google Play Store.



1626
1627
1628
1629
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1626

class AndroidKeySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end