Class: Google::Cloud::RecaptchaEnterprise::V1::AssessmentEnvironment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

The environment creating the assessment. This describes your environment (the system invoking CreateAssessment), NOT the environment of your user.

Instance Attribute Summary collapse

Instance Attribute Details

#client::String

Returns Optional. Identifies the client module initiating the CreateAssessment request. This can be the link to the client module's project. Examples include:

- "github.com/GoogleCloudPlatform/recaptcha-enterprise-google-tag-manager"

  • "wordpress.org/plugins/recaptcha-something".

Returns:

  • (::String)

    Optional. Identifies the client module initiating the CreateAssessment request. This can be the link to the client module's project. Examples include:

    - "github.com/GoogleCloudPlatform/recaptcha-enterprise-google-tag-manager"

    • "wordpress.org/plugins/recaptcha-something"


2194
2195
2196
2197
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 2194

class AssessmentEnvironment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version::String

Returns Optional. The version of the client module. For example, "1.0.0".

Returns:

  • (::String)

    Optional. The version of the client module. For example, "1.0.0".



2194
2195
2196
2197
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 2194

class AssessmentEnvironment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end