Class: Google::Cloud::RecaptchaEnterprise::V1::Bot

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Bot information and metadata.

Defined Under Namespace

Modules: BotType

Instance Attribute Summary collapse

Instance Attribute Details

#bot_type::Google::Cloud::RecaptchaEnterprise::V1::Bot::BotType

Returns Optional. Enumerated field representing the type of bot.

Returns:



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 847

class Bot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of bots.
  # Ensure that applications can handle values not explicitly listed.
  module BotType
    # Default unspecified type.
    BOT_TYPE_UNSPECIFIED = 0

    # Software program that interacts with a site and performs tasks
    # autonomously.
    AI_AGENT = 1

    # Software that extracts specific data from sites for use.
    CONTENT_SCRAPER = 2

    # Software that crawls sites and stores content for the purpose of
    # efficient retrieval, likely as part of a search engine.
    SEARCH_INDEXER = 3
  end
end

#name::String

Returns Optional. Enumerated string value that indicates the identity of the bot, formatted in kebab-case.

Returns:

  • (::String)

    Optional. Enumerated string value that indicates the identity of the bot, formatted in kebab-case.



847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 847

class Bot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of bots.
  # Ensure that applications can handle values not explicitly listed.
  module BotType
    # Default unspecified type.
    BOT_TYPE_UNSPECIFIED = 0

    # Software program that interacts with a site and performs tasks
    # autonomously.
    AI_AGENT = 1

    # Software that extracts specific data from sites for use.
    CONTENT_SCRAPER = 2

    # Software that crawls sites and stores content for the purpose of
    # efficient retrieval, likely as part of a search engine.
    SEARCH_INDEXER = 3
  end
end