Class: Google::Cloud::RecaptchaEnterprise::V1::Event

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

The event being assessed.

Defined Under Namespace

Modules: FraudPrevention

Instance Attribute Summary collapse

Instance Attribute Details

#expected_action::String

Returns Optional. The expected action for this type of event. This should be the same action provided at token generation time on client-side platforms already integrated with recaptcha enterprise.

Returns:

  • (::String)

    Optional. The expected action for this type of event. This should be the same action provided at token generation time on client-side platforms already integrated with recaptcha enterprise.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#express::Boolean

Returns Optional. Flag for a reCAPTCHA express request for an assessment without a token. If enabled, site_key must reference an Express site key.

Returns:

  • (::Boolean)

    Optional. Flag for a reCAPTCHA express request for an assessment without a token. If enabled, site_key must reference an Express site key.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#firewall_policy_evaluation::Boolean

Returns Optional. Flag for enabling firewall policy config assessment. If this flag is enabled, the firewall policy is evaluated and a suggested firewall action is returned in the response.

Returns:

  • (::Boolean)

    Optional. Flag for enabling firewall policy config assessment. If this flag is enabled, the firewall policy is evaluated and a suggested firewall action is returned in the response.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#fraud_prevention::Google::Cloud::RecaptchaEnterprise::V1::Event::FraudPrevention

Returns Optional. The Fraud Prevention setting for this assessment.

Returns:



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#hashed_account_id::String

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Deprecated: use user_info.account_id instead. Unique stable hashed user identifier for the request. The identifier must be hashed using hmac-sha256 with stable secret.

Returns:

  • (::String)

    Optional. Deprecated: use user_info.account_id instead. Unique stable hashed user identifier for the request. The identifier must be hashed using hmac-sha256 with stable secret.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#headers::Array<::String>

Returns Optional. HTTP header information about the request.

Returns:

  • (::Array<::String>)

    Optional. HTTP header information about the request.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#ja3::String

Returns Optional. JA3 fingerprint for SSL clients. To learn how to compute this fingerprint, please refer to https://github.com/salesforce/ja3.

Returns:



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#ja4::String

Returns Optional. JA4 fingerprint for SSL clients. To learn how to compute this fingerprint, please refer to https://github.com/FoxIO-LLC/ja4.

Returns:



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#requested_uri::String

Returns Optional. The URI resource the user requested that triggered an assessment.

Returns:

  • (::String)

    Optional. The URI resource the user requested that triggered an assessment.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#site_key::String

Returns Optional. The site key that was used to invoke reCAPTCHA Enterprise on your site and generate the token.

Returns:

  • (::String)

    Optional. The site key that was used to invoke reCAPTCHA Enterprise on your site and generate the token.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#token::String

Returns Optional. The user response token provided by the reCAPTCHA Enterprise client-side integration on your site.

Returns:

  • (::String)

    Optional. The user response token provided by the reCAPTCHA Enterprise client-side integration on your site.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#transaction_data::Google::Cloud::RecaptchaEnterprise::V1::TransactionData

Returns Optional. Data describing a payment transaction to be assessed. Sending this data enables reCAPTCHA Enterprise Fraud Prevention and the FraudPreventionAssessment component in the response.

Returns:



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#user_agent::String

Returns Optional. The user agent present in the request from the user's device related to this event.

Returns:

  • (::String)

    Optional. The user agent present in the request from the user's device related to this event.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#user_info::Google::Cloud::RecaptchaEnterprise::V1::UserInfo

Returns Optional. Information about the user that generates this event, when they can be identified. They are often identified through the use of an account for logged-in requests or login/registration requests, or by providing user identifiers for guest actions like checkout.

Returns:

  • (::Google::Cloud::RecaptchaEnterprise::V1::UserInfo)

    Optional. Information about the user that generates this event, when they can be identified. They are often identified through the use of an account for logged-in requests or login/registration requests, or by providing user identifiers for guest actions like checkout.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#user_ip_address::String

Returns Optional. The IP address in the request from the user's device related to this event.

Returns:

  • (::String)

    Optional. The IP address in the request from the user's device related to this event.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end

#waf_token_assessment::Boolean

Returns Optional. Flag for running Web Application Firewall (WAF) token assessment. If enabled, the token must be specified, and have been created by a WAF-enabled key.

Returns:

  • (::Boolean)

    Optional. Flag for running Web Application Firewall (WAF) token assessment. If enabled, the token must be specified, and have been created by a WAF-enabled key.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 543

class Event
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Setting that controls Fraud Prevention assessments.
  # Ensure that applications can handle values not explicitly listed.
  module FraudPrevention
    # Default, unspecified setting. `fraud_prevention_assessment` is returned
    # if `transaction_data` is present in `Event` and Fraud Prevention is
    # enabled in the Google Cloud console.
    FRAUD_PREVENTION_UNSPECIFIED = 0

    # Enable Fraud Prevention for this assessment, if Fraud Prevention is
    # enabled in the Google Cloud console.
    ENABLED = 1

    # Disable Fraud Prevention for this assessment, regardless of the Google
    # Cloud console settings.
    DISABLED = 2
  end
end