Class: Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Risk reasons applicable to the Fraud Prevention assessment.

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Attribute Details

#reason::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason (readonly)

Returns Output only. Risk reasons applicable to the Fraud Prevention assessment.

Returns:



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 969

class RiskReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Risk reasons applicable to the Fraud Prevention assessment. New risk
  # reasons will be added over time.
  module Reason
    # Default unspecified type.
    REASON_UNSPECIFIED = 0

    # A suspiciously high number of recent transactions have used identifiers
    # present in this transaction.
    HIGH_TRANSACTION_VELOCITY = 1

    # User is cycling through a suspiciously large number of identifiers,
    # suggesting enumeration or validation attacks within a potential fraud
    # network.
    EXCESSIVE_ENUMERATION_PATTERN = 2

    # User has a short history or no history in the reCAPTCHA network,
    # suggesting the possibility of synthetic identity generation.
    SHORT_IDENTITY_HISTORY = 3

    # Identifiers used in this transaction originate from an unusual or
    # conflicting set of geolocations.
    GEOLOCATION_DISCREPANCY = 4

    # This transaction is linked to a cluster of known fraudulent activity.
    ASSOCIATED_WITH_FRAUD_CLUSTER = 5
  end
end