Module: Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason

Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Risk reasons applicable to the Fraud Prevention assessment. New risk reasons will be added over time.

Constant Summary collapse

REASON_UNSPECIFIED =

Default unspecified type.

0
HIGH_TRANSACTION_VELOCITY =

A suspiciously high number of recent transactions have used identifiers present in this transaction.

1
EXCESSIVE_ENUMERATION_PATTERN =

User is cycling through a suspiciously large number of identifiers, suggesting enumeration or validation attacks within a potential fraud network.

2
SHORT_IDENTITY_HISTORY =

User has a short history or no history in the reCAPTCHA network, suggesting the possibility of synthetic identity generation.

3
GEOLOCATION_DISCREPANCY =

Identifiers used in this transaction originate from an unusual or conflicting set of geolocations.

4
ASSOCIATED_WITH_FRAUD_CLUSTER =

This transaction is linked to a cluster of known fraudulent activity.

5