Class: Google::Cloud::RecaptchaEnterprise::V1::FraudSignals

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Fraud signals describing users and cards involved in the transaction.

Defined Under Namespace

Classes: CardSignals, UserSignals

Instance Attribute Summary collapse

Instance Attribute Details

#card_signals::Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals (readonly)

Returns Output only. Signals describing the payment card or cards used in this transaction.

Returns:



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1043

class FraudSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Signals describing the user involved in this transaction.
  # @!attribute [r] active_days_lower_bound
  #   @return [::Integer]
  #     Output only. This user (based on email, phone, and other identifiers) has
  #     been seen on the internet for at least this number of days.
  # @!attribute [r] synthetic_risk
  #   @return [::Float]
  #     Output only. Likelihood (from 0.0 to 1.0) this user includes synthetic
  #     components in their identity, such as a randomly generated email address,
  #     temporary phone number, or fake shipping address.
  class UserSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Signals describing the payment card used in this transaction.
  # @!attribute [r] card_labels
  #   @return [::Array<::Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals::CardLabel>]
  #     Output only. The labels for the payment card in this transaction.
  class CardSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Risk labels describing the card being assessed, such as its funding
    # mechanism.
    # Ensure that applications can handle values not explicitly listed.
    module CardLabel
      # No label specified.
      CARD_LABEL_UNSPECIFIED = 0

      # This card has been detected as prepaid.
      PREPAID = 1

      # This card has been detected as virtual, such as a card number generated
      # for a single transaction or merchant.
      VIRTUAL = 2

      # This card has been detected as being used in an unexpected geographic
      # location.
      UNEXPECTED_LOCATION = 3
    end
  end
end

#user_signals::Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::UserSignals (readonly)

Returns Output only. Signals describing the end user in this transaction.

Returns:



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1043

class FraudSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Signals describing the user involved in this transaction.
  # @!attribute [r] active_days_lower_bound
  #   @return [::Integer]
  #     Output only. This user (based on email, phone, and other identifiers) has
  #     been seen on the internet for at least this number of days.
  # @!attribute [r] synthetic_risk
  #   @return [::Float]
  #     Output only. Likelihood (from 0.0 to 1.0) this user includes synthetic
  #     components in their identity, such as a randomly generated email address,
  #     temporary phone number, or fake shipping address.
  class UserSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Signals describing the payment card used in this transaction.
  # @!attribute [r] card_labels
  #   @return [::Array<::Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals::CardLabel>]
  #     Output only. The labels for the payment card in this transaction.
  class CardSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Risk labels describing the card being assessed, such as its funding
    # mechanism.
    # Ensure that applications can handle values not explicitly listed.
    module CardLabel
      # No label specified.
      CARD_LABEL_UNSPECIFIED = 0

      # This card has been detected as prepaid.
      PREPAID = 1

      # This card has been detected as virtual, such as a card number generated
      # for a single transaction or merchant.
      VIRTUAL = 2

      # This card has been detected as being used in an unexpected geographic
      # location.
      UNEXPECTED_LOCATION = 3
    end
  end
end