Class: Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Signals describing the payment card used in this transaction.
Defined Under Namespace
Modules: CardLabel
Instance Attribute Summary collapse
-
#card_labels ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals::CardLabel>
readonly
Output only.
Instance Attribute Details
#card_labels ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::FraudSignals::CardSignals::CardLabel> (readonly)
Returns Output only. The labels for the payment card in this transaction.
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1066 class CardSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk labels describing the card being assessed, such as its funding # mechanism. # Ensure that applications can handle values not explicitly listed. module CardLabel # No label specified. CARD_LABEL_UNSPECIFIED = 0 # This card has been detected as prepaid. PREPAID = 1 # This card has been detected as virtual, such as a card number generated # for a single transaction or merchant. VIRTUAL = 2 # This card has been detected as being used in an unexpected geographic # location. UNEXPECTED_LOCATION = 3 end end |