Class: Google::Cloud::RecaptchaEnterprise::V1::IpOverrideData
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::IpOverrideData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Information about the IP or IP range override.
Defined Under Namespace
Modules: OverrideType
Instance Attribute Summary collapse
-
#ip ⇒ ::String
Required.
-
#override_type ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::IpOverrideData::OverrideType
Required.
Instance Attribute Details
#ip ⇒ ::String
Returns Required. The IP address to override (can be IPv4, IPv6 or CIDR). The IP override must be a valid IPv4 or IPv6 address, or a CIDR range. The IP override must be a public IP address. Example of IPv4: 168.192.5.6 Example of IPv6: 2001:0000:130F:0000:0000:09C0:876A:130B Example of IPv4 with CIDR: 168.192.5.0/24 Example of IPv6 with CIDR: 2001:0DB8:1234::/48.
2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 2212 class IpOverrideData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the type of IP override. # Ensure that applications can handle values not explicitly listed. module OverrideType # Default override type that indicates this enum hasn't been specified. OVERRIDE_TYPE_UNSPECIFIED = 0 # Allowlist the IP address; i.e. give a `risk_analysis.score` of 0.9 for # all valid assessments. ALLOW = 1 end end |
#override_type ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::IpOverrideData::OverrideType
Returns Required. Describes the type of IP override.
2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 2212 class IpOverrideData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the type of IP override. # Ensure that applications can handle values not explicitly listed. module OverrideType # Default override type that indicates this enum hasn't been specified. OVERRIDE_TYPE_UNSPECIFIED = 0 # Allowlist the IP address; i.e. give a `risk_analysis.score` of 0.9 for # all valid assessments. ALLOW = 1 end end |