Class: Google::Cloud::RecaptchaEnterprise::V1::RiskAnalysis

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Risk analysis result for an event.

Defined Under Namespace

Modules: Challenge, ClassificationReason

Instance Attribute Summary collapse

Instance Attribute Details

#challenge::Google::Cloud::RecaptchaEnterprise::V1::RiskAnalysis::Challenge (readonly)

Returns Output only. Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys.

Returns:



787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 787

class RiskAnalysis
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reasons contributing to the risk analysis verdict.
  # Ensure that applications can handle values not explicitly listed.
  module ClassificationReason
    # Default unspecified type.
    CLASSIFICATION_REASON_UNSPECIFIED = 0

    # Interactions matched the behavior of an automated agent.
    AUTOMATION = 1

    # The event originated from an illegitimate environment.
    UNEXPECTED_ENVIRONMENT = 2

    # Traffic volume from the event source is higher than normal.
    TOO_MUCH_TRAFFIC = 3

    # Interactions with the site were significantly different than expected
    # patterns.
    UNEXPECTED_USAGE_PATTERNS = 4

    # Too little traffic has been received from this site thus far to generate
    # quality risk analysis.
    LOW_CONFIDENCE_SCORE = 5

    # The request matches behavioral characteristics of a carding attack.
    SUSPECTED_CARDING = 6

    # The request matches behavioral characteristics of chargebacks for fraud.
    SUSPECTED_CHARGEBACK = 7
  end

  # Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys.
  # Ensure that applications can handle values not explicitly listed.
  module Challenge
    # Default unspecified type.
    CHALLENGE_UNSPECIFIED = 0

    # No challenge was presented for solving.
    NOCAPTCHA = 1

    # A solution was submitted that was correct.
    PASSED = 2

    # A solution was submitted that was incorrect or otherwise
    # deemed suspicious.
    FAILED = 3
  end
end

#extended_verdict_reasons::Array<::String> (readonly)

Returns Output only. Extended verdict reasons to be used for experimentation only. The set of possible reasons is subject to change.

Returns:

  • (::Array<::String>)

    Output only. Extended verdict reasons to be used for experimentation only. The set of possible reasons is subject to change.



787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 787

class RiskAnalysis
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reasons contributing to the risk analysis verdict.
  # Ensure that applications can handle values not explicitly listed.
  module ClassificationReason
    # Default unspecified type.
    CLASSIFICATION_REASON_UNSPECIFIED = 0

    # Interactions matched the behavior of an automated agent.
    AUTOMATION = 1

    # The event originated from an illegitimate environment.
    UNEXPECTED_ENVIRONMENT = 2

    # Traffic volume from the event source is higher than normal.
    TOO_MUCH_TRAFFIC = 3

    # Interactions with the site were significantly different than expected
    # patterns.
    UNEXPECTED_USAGE_PATTERNS = 4

    # Too little traffic has been received from this site thus far to generate
    # quality risk analysis.
    LOW_CONFIDENCE_SCORE = 5

    # The request matches behavioral characteristics of a carding attack.
    SUSPECTED_CARDING = 6

    # The request matches behavioral characteristics of chargebacks for fraud.
    SUSPECTED_CHARGEBACK = 7
  end

  # Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys.
  # Ensure that applications can handle values not explicitly listed.
  module Challenge
    # Default unspecified type.
    CHALLENGE_UNSPECIFIED = 0

    # No challenge was presented for solving.
    NOCAPTCHA = 1

    # A solution was submitted that was correct.
    PASSED = 2

    # A solution was submitted that was incorrect or otherwise
    # deemed suspicious.
    FAILED = 3
  end
end

#reasons::Array<::Google::Cloud::RecaptchaEnterprise::V1::RiskAnalysis::ClassificationReason> (readonly)

Returns Output only. Reasons contributing to the risk analysis verdict.

Returns:



787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 787

class RiskAnalysis
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reasons contributing to the risk analysis verdict.
  # Ensure that applications can handle values not explicitly listed.
  module ClassificationReason
    # Default unspecified type.
    CLASSIFICATION_REASON_UNSPECIFIED = 0

    # Interactions matched the behavior of an automated agent.
    AUTOMATION = 1

    # The event originated from an illegitimate environment.
    UNEXPECTED_ENVIRONMENT = 2

    # Traffic volume from the event source is higher than normal.
    TOO_MUCH_TRAFFIC = 3

    # Interactions with the site were significantly different than expected
    # patterns.
    UNEXPECTED_USAGE_PATTERNS = 4

    # Too little traffic has been received from this site thus far to generate
    # quality risk analysis.
    LOW_CONFIDENCE_SCORE = 5

    # The request matches behavioral characteristics of a carding attack.
    SUSPECTED_CARDING = 6

    # The request matches behavioral characteristics of chargebacks for fraud.
    SUSPECTED_CHARGEBACK = 7
  end

  # Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys.
  # Ensure that applications can handle values not explicitly listed.
  module Challenge
    # Default unspecified type.
    CHALLENGE_UNSPECIFIED = 0

    # No challenge was presented for solving.
    NOCAPTCHA = 1

    # A solution was submitted that was correct.
    PASSED = 2

    # A solution was submitted that was incorrect or otherwise
    # deemed suspicious.
    FAILED = 3
  end
end

#score::Float (readonly)

Returns Output only. Legitimate event score from 0.0 to 1.0. (1.0 means very likely legitimate traffic while 0.0 means very likely non-legitimate traffic).

Returns:

  • (::Float)

    Output only. Legitimate event score from 0.0 to 1.0. (1.0 means very likely legitimate traffic while 0.0 means very likely non-legitimate traffic).



787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 787

class RiskAnalysis
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reasons contributing to the risk analysis verdict.
  # Ensure that applications can handle values not explicitly listed.
  module ClassificationReason
    # Default unspecified type.
    CLASSIFICATION_REASON_UNSPECIFIED = 0

    # Interactions matched the behavior of an automated agent.
    AUTOMATION = 1

    # The event originated from an illegitimate environment.
    UNEXPECTED_ENVIRONMENT = 2

    # Traffic volume from the event source is higher than normal.
    TOO_MUCH_TRAFFIC = 3

    # Interactions with the site were significantly different than expected
    # patterns.
    UNEXPECTED_USAGE_PATTERNS = 4

    # Too little traffic has been received from this site thus far to generate
    # quality risk analysis.
    LOW_CONFIDENCE_SCORE = 5

    # The request matches behavioral characteristics of a carding attack.
    SUSPECTED_CARDING = 6

    # The request matches behavioral characteristics of chargebacks for fraud.
    SUSPECTED_CHARGEBACK = 7
  end

  # Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys.
  # Ensure that applications can handle values not explicitly listed.
  module Challenge
    # Default unspecified type.
    CHALLENGE_UNSPECIFIED = 0

    # No challenge was presented for solving.
    NOCAPTCHA = 1

    # A solution was submitted that was correct.
    PASSED = 2

    # A solution was submitted that was incorrect or otherwise
    # deemed suspicious.
    FAILED = 3
  end
end

#verified_bots::Array<::Google::Cloud::RecaptchaEnterprise::V1::Bot> (readonly)

Returns Output only. Bots with identities that have been verified by reCAPTCHA and detected in the event.

Returns:



787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 787

class RiskAnalysis
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Reasons contributing to the risk analysis verdict.
  # Ensure that applications can handle values not explicitly listed.
  module ClassificationReason
    # Default unspecified type.
    CLASSIFICATION_REASON_UNSPECIFIED = 0

    # Interactions matched the behavior of an automated agent.
    AUTOMATION = 1

    # The event originated from an illegitimate environment.
    UNEXPECTED_ENVIRONMENT = 2

    # Traffic volume from the event source is higher than normal.
    TOO_MUCH_TRAFFIC = 3

    # Interactions with the site were significantly different than expected
    # patterns.
    UNEXPECTED_USAGE_PATTERNS = 4

    # Too little traffic has been received from this site thus far to generate
    # quality risk analysis.
    LOW_CONFIDENCE_SCORE = 5

    # The request matches behavioral characteristics of a carding attack.
    SUSPECTED_CARDING = 6

    # The request matches behavioral characteristics of chargebacks for fraud.
    SUSPECTED_CHARGEBACK = 7
  end

  # Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys.
  # Ensure that applications can handle values not explicitly listed.
  module Challenge
    # Default unspecified type.
    CHALLENGE_UNSPECIFIED = 0

    # No challenge was presented for solving.
    NOCAPTCHA = 1

    # A solution was submitted that was correct.
    PASSED = 2

    # A solution was submitted that was incorrect or otherwise
    # deemed suspicious.
    FAILED = 3
  end
end