Class: Google::Cloud::RecaptchaEnterprise::V1::TestingOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Options for user acceptance testing.

Defined Under Namespace

Modules: TestingChallenge

Instance Attribute Summary collapse

Instance Attribute Details

#testing_challenge::Google::Cloud::RecaptchaEnterprise::V1::TestingOptions::TestingChallenge

Returns Optional. For challenge-based keys only (CHECKBOX, INVISIBLE), all challenge requests for this site return nocaptcha if NOCAPTCHA, or an unsolvable challenge if CHALLENGE.

Returns:



1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1471

class TestingOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that represents the challenge option for challenge-based (for example,
  # CHECKBOX and INVISIBLE) testing keys.
  # Ensure that applications can handle values not explicitly listed.
  module TestingChallenge
    # Perform the normal risk analysis and return either nocaptcha or a
    # challenge depending on risk and trust factors.
    TESTING_CHALLENGE_UNSPECIFIED = 0

    # Challenge requests for this key always return a nocaptcha, which
    # does not require a solution.
    NOCAPTCHA = 1

    # Challenge requests for this key always return an unsolvable
    # challenge.
    UNSOLVABLE_CHALLENGE = 2
  end
end

#testing_score::Float

Returns Optional. All assessments for this Key return this score. Must be between 0 (likely not legitimate) and 1 (likely legitimate) inclusive.

Returns:

  • (::Float)

    Optional. All assessments for this Key return this score. Must be between 0 (likely not legitimate) and 1 (likely legitimate) inclusive.



1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1471

class TestingOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum that represents the challenge option for challenge-based (for example,
  # CHECKBOX and INVISIBLE) testing keys.
  # Ensure that applications can handle values not explicitly listed.
  module TestingChallenge
    # Perform the normal risk analysis and return either nocaptcha or a
    # challenge depending on risk and trust factors.
    TESTING_CHALLENGE_UNSPECIFIED = 0

    # Challenge requests for this key always return a nocaptcha, which
    # does not require a solution.
    NOCAPTCHA = 1

    # Challenge requests for this key always return an unsolvable
    # challenge.
    UNSOLVABLE_CHALLENGE = 2
  end
end