Module: Google::Cloud::RecaptchaEnterprise::V1::TestingOptions::TestingChallenge

Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Enum that represents the challenge option for challenge-based (for example, CHECKBOX and INVISIBLE) testing keys. Ensure that applications can handle values not explicitly listed.

Constant Summary collapse

TESTING_CHALLENGE_UNSPECIFIED =

Perform the normal risk analysis and return either nocaptcha or a challenge depending on risk and trust factors.

0
NOCAPTCHA =

Challenge requests for this key always return a nocaptcha, which does not require a solution.

1
UNSOLVABLE_CHALLENGE =

Challenge requests for this key always return an unsolvable challenge.

2