Module: Google::Cloud::RecaptchaEnterprise::V1::TokenProperties::InvalidReason

Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Enum that represents the types of invalid token reasons. Ensure that applications can handle values not explicitly listed.

Constant Summary collapse

INVALID_REASON_UNSPECIFIED =

Default unspecified type.

0
UNKNOWN_INVALID_REASON =

If the failure reason was not accounted for.

1
MALFORMED =

The provided user verification token was malformed.

2
EXPIRED =

The user verification token had expired.

3
DUPE =

The user verification had already been seen.

4
MISSING =

The user verification token was not present.

5
BROWSER_ERROR =

A retriable error (such as network failure) occurred on the browser. Could easily be simulated by an attacker.

6
UNEXPECTED_ACTION =

The action provided at token generation was different than the expected_action in the assessment request. The comparison is case-insensitive. This reason can only be returned if all of the following are true:

  • your site_key has the POLICY_BASED_CHALLENGE integration type
  • you set an action score threshold higher than 0.0
  • you provided a non-empty expected_action
7