Class: Google::Cloud::RecaptchaEnterprise::V1::TransactionData::Address
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::TransactionData::Address
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Structured address format for billing and shipping addresses.
Instance Attribute Summary collapse
-
#address ⇒ ::Array<::String>
Optional.
-
#administrative_area ⇒ ::String
Optional.
-
#locality ⇒ ::String
Optional.
-
#postal_code ⇒ ::String
Optional.
-
#recipient ⇒ ::String
Optional.
-
#region_code ⇒ ::String
Optional.
Instance Attribute Details
#address ⇒ ::Array<::String>
Returns Optional. The first lines of the address. The first line generally contains the street name and number, and further lines may include information such as an apartment number.
647 648 649 650 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 647 class Address include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#administrative_area ⇒ ::String
Returns Optional. The state, province, or otherwise administrative area of the address.
647 648 649 650 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 647 class Address include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#locality ⇒ ::String
Returns Optional. The town/city of the address.
647 648 649 650 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 647 class Address include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#postal_code ⇒ ::String
Returns Optional. The postal or ZIP code of the address.
647 648 649 650 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 647 class Address include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recipient ⇒ ::String
Returns Optional. The recipient name, potentially including information such as "care of".
647 648 649 650 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 647 class Address include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |