Module: Google::Cloud::RecaptchaEnterprise::V1::WafSettings::WafFeature

Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Supported WAF features. For more information, see https://cloud.google.com/recaptcha/docs/usecase#comparison_of_features. Ensure that applications can handle values not explicitly listed.

Constant Summary collapse

WAF_FEATURE_UNSPECIFIED =

Undefined feature.

0
CHALLENGE_PAGE =

Redirects suspicious traffic to reCAPTCHA.

1
SESSION_TOKEN =

Use reCAPTCHA session-tokens to protect the whole user session on the site's domain.

2
ACTION_TOKEN =

Use reCAPTCHA action-tokens to protect user actions.

3
EXPRESS =

Deprecated: Use express_settings instead.

5