Class: Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ChallengeSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb

Overview

Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is triggered.

Defined Under Namespace

Classes: ActionSettingsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#action_settings::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}

Returns Optional. The action to score threshold map. The action name should be the same as the action name passed in the data-action attribute (see https://cloud.google.com/recaptcha/docs/actions-website). Action names are case-insensitive. There is a maximum of 100 action settings. An action name has a maximum length of 100.

Returns:



1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1551

class ChallengeSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings]
  class ActionSettingsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#default_settings::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings

Returns Required. Defines when a challenge is triggered (unless the default threshold is overridden for the given action, see action_settings).

Returns:



1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1551

class ChallengeSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings]
  class ActionSettingsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end