Class: Google::Cloud::RecaptchaEnterprise::V1::FirewallAction
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::FirewallAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
An individual action. Each action represents what to do if a policy matches.
Defined Under Namespace
Classes: AllowAction, BlockAction, IncludeRecaptchaScriptAction, RedirectAction, SetHeaderAction, SubstituteAction
Instance Attribute Summary collapse
-
#allow ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::AllowAction
The user request did not match any policy and should be allowed access to the requested resource.
-
#block ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::BlockAction
This action denies access to a given page.
-
#include_recaptcha_script ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::IncludeRecaptchaScriptAction
This action injects reCAPTCHA JavaScript code into the HTML page returned by the site backend.
-
#redirect ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::RedirectAction
This action redirects the request to a reCAPTCHA interstitial to attach a token.
-
#set_header ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::SetHeaderAction
This action sets a custom header but allow the request to continue to the customer backend.
-
#substitute ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::SubstituteAction
This action transparently serves a different page to an offending user.
Instance Attribute Details
#allow ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::AllowAction
Returns The user request did not match any policy and should be allowed access to the requested resource.
Note: The following fields are mutually exclusive: allow, block, include_recaptcha_script, redirect, substitute, set_header. If a field in that set is populated, all other fields in the set will automatically be cleared.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1797 class FirewallAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An allow action continues processing a request unimpeded. class AllowAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A block action serves an HTTP error code a prevents the request from # hitting the backend. class BlockAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An include reCAPTCHA script action involves injecting reCAPTCHA JavaScript # code into the HTML returned by the site backend. This reCAPTCHA # script is tasked with collecting user signals on the requested web page, # issuing tokens as a cookie within the site domain, and enabling their # utilization in subsequent page requests. class IncludeRecaptchaScriptAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A redirect action returns a 307 (temporary redirect) response, pointing # the user to a reCAPTCHA interstitial page to attach a token. class RedirectAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A substitute action transparently serves a different page than the one # requested. # @!attribute [rw] path # @return [::String] # Optional. The address to redirect to. The target is a relative path in # the current host. Example: "/blog/404.html". class SubstituteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set header action sets a header and forwards the request to the # backend. This can be used to trigger custom protection implemented on the # backend. # @!attribute [rw] key # @return [::String] # Optional. The header key to set in the request to the backend server. # @!attribute [rw] value # @return [::String] # Optional. The header value to set in the request to the backend server. class SetHeaderAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#block ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::BlockAction
Returns This action denies access to a given page. The user gets an HTTP error code.
Note: The following fields are mutually exclusive: block, allow, include_recaptcha_script, redirect, substitute, set_header. If a field in that set is populated, all other fields in the set will automatically be cleared.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1797 class FirewallAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An allow action continues processing a request unimpeded. class AllowAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A block action serves an HTTP error code a prevents the request from # hitting the backend. class BlockAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An include reCAPTCHA script action involves injecting reCAPTCHA JavaScript # code into the HTML returned by the site backend. This reCAPTCHA # script is tasked with collecting user signals on the requested web page, # issuing tokens as a cookie within the site domain, and enabling their # utilization in subsequent page requests. class IncludeRecaptchaScriptAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A redirect action returns a 307 (temporary redirect) response, pointing # the user to a reCAPTCHA interstitial page to attach a token. class RedirectAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A substitute action transparently serves a different page than the one # requested. # @!attribute [rw] path # @return [::String] # Optional. The address to redirect to. The target is a relative path in # the current host. Example: "/blog/404.html". class SubstituteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set header action sets a header and forwards the request to the # backend. This can be used to trigger custom protection implemented on the # backend. # @!attribute [rw] key # @return [::String] # Optional. The header key to set in the request to the backend server. # @!attribute [rw] value # @return [::String] # Optional. The header value to set in the request to the backend server. class SetHeaderAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#include_recaptcha_script ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::IncludeRecaptchaScriptAction
This action injects reCAPTCHA JavaScript code into the HTML page returned by the site backend.
Note: The following fields are mutually exclusive: include_recaptcha_script, allow, block, redirect, substitute, set_header. If a field in that set is populated, all other fields in the set will automatically be cleared.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1797 class FirewallAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An allow action continues processing a request unimpeded. class AllowAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A block action serves an HTTP error code a prevents the request from # hitting the backend. class BlockAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An include reCAPTCHA script action involves injecting reCAPTCHA JavaScript # code into the HTML returned by the site backend. This reCAPTCHA # script is tasked with collecting user signals on the requested web page, # issuing tokens as a cookie within the site domain, and enabling their # utilization in subsequent page requests. class IncludeRecaptchaScriptAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A redirect action returns a 307 (temporary redirect) response, pointing # the user to a reCAPTCHA interstitial page to attach a token. class RedirectAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A substitute action transparently serves a different page than the one # requested. # @!attribute [rw] path # @return [::String] # Optional. The address to redirect to. The target is a relative path in # the current host. Example: "/blog/404.html". class SubstituteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set header action sets a header and forwards the request to the # backend. This can be used to trigger custom protection implemented on the # backend. # @!attribute [rw] key # @return [::String] # Optional. The header key to set in the request to the backend server. # @!attribute [rw] value # @return [::String] # Optional. The header value to set in the request to the backend server. class SetHeaderAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#redirect ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::RedirectAction
Returns This action redirects the request to a reCAPTCHA interstitial to attach a token.
Note: The following fields are mutually exclusive: redirect, allow, block, include_recaptcha_script, substitute, set_header. If a field in that set is populated, all other fields in the set will automatically be cleared.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1797 class FirewallAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An allow action continues processing a request unimpeded. class AllowAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A block action serves an HTTP error code a prevents the request from # hitting the backend. class BlockAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An include reCAPTCHA script action involves injecting reCAPTCHA JavaScript # code into the HTML returned by the site backend. This reCAPTCHA # script is tasked with collecting user signals on the requested web page, # issuing tokens as a cookie within the site domain, and enabling their # utilization in subsequent page requests. class IncludeRecaptchaScriptAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A redirect action returns a 307 (temporary redirect) response, pointing # the user to a reCAPTCHA interstitial page to attach a token. class RedirectAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A substitute action transparently serves a different page than the one # requested. # @!attribute [rw] path # @return [::String] # Optional. The address to redirect to. The target is a relative path in # the current host. Example: "/blog/404.html". class SubstituteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set header action sets a header and forwards the request to the # backend. This can be used to trigger custom protection implemented on the # backend. # @!attribute [rw] key # @return [::String] # Optional. The header key to set in the request to the backend server. # @!attribute [rw] value # @return [::String] # Optional. The header value to set in the request to the backend server. class SetHeaderAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#set_header ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::SetHeaderAction
Returns This action sets a custom header but allow the request to continue to the customer backend.
Note: The following fields are mutually exclusive: set_header, allow, block, include_recaptcha_script, redirect, substitute. If a field in that set is populated, all other fields in the set will automatically be cleared.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1797 class FirewallAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An allow action continues processing a request unimpeded. class AllowAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A block action serves an HTTP error code a prevents the request from # hitting the backend. class BlockAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An include reCAPTCHA script action involves injecting reCAPTCHA JavaScript # code into the HTML returned by the site backend. This reCAPTCHA # script is tasked with collecting user signals on the requested web page, # issuing tokens as a cookie within the site domain, and enabling their # utilization in subsequent page requests. class IncludeRecaptchaScriptAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A redirect action returns a 307 (temporary redirect) response, pointing # the user to a reCAPTCHA interstitial page to attach a token. class RedirectAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A substitute action transparently serves a different page than the one # requested. # @!attribute [rw] path # @return [::String] # Optional. The address to redirect to. The target is a relative path in # the current host. Example: "/blog/404.html". class SubstituteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set header action sets a header and forwards the request to the # backend. This can be used to trigger custom protection implemented on the # backend. # @!attribute [rw] key # @return [::String] # Optional. The header key to set in the request to the backend server. # @!attribute [rw] value # @return [::String] # Optional. The header value to set in the request to the backend server. class SetHeaderAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#substitute ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FirewallAction::SubstituteAction
Returns This action transparently serves a different page to an offending user.
Note: The following fields are mutually exclusive: substitute, allow, block, include_recaptcha_script, redirect, set_header. If a field in that set is populated, all other fields in the set will automatically be cleared.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1797 class FirewallAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An allow action continues processing a request unimpeded. class AllowAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A block action serves an HTTP error code a prevents the request from # hitting the backend. class BlockAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An include reCAPTCHA script action involves injecting reCAPTCHA JavaScript # code into the HTML returned by the site backend. This reCAPTCHA # script is tasked with collecting user signals on the requested web page, # issuing tokens as a cookie within the site domain, and enabling their # utilization in subsequent page requests. class IncludeRecaptchaScriptAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A redirect action returns a 307 (temporary redirect) response, pointing # the user to a reCAPTCHA interstitial page to attach a token. class RedirectAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A substitute action transparently serves a different page than the one # requested. # @!attribute [rw] path # @return [::String] # Optional. The address to redirect to. The target is a relative path in # the current host. Example: "/blog/404.html". class SubstituteAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A set header action sets a header and forwards the request to the # backend. This can be used to trigger custom protection implemented on the # backend. # @!attribute [rw] key # @return [::String] # Optional. The header key to set in the request to the backend server. # @!attribute [rw] value # @return [::String] # Optional. The header value to set in the request to the backend server. class SetHeaderAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |