Class: Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Assessment for Fraud Prevention.
Defined Under Namespace
Classes: BehavioralTrustVerdict, CardTestingVerdict, RiskReason, StolenInstrumentVerdict
Instance Attribute Summary collapse
-
#behavioral_trust_verdict ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::BehavioralTrustVerdict
readonly
Output only.
-
#card_testing_verdict ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::CardTestingVerdict
readonly
Output only.
-
#risk_reasons ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason>
readonly
Output only.
-
#stolen_instrument_verdict ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::StolenInstrumentVerdict
readonly
Output only.
-
#transaction_risk ⇒ ::Float
readonly
Output only.
Instance Attribute Details
#behavioral_trust_verdict ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::BehavioralTrustVerdict (readonly)
Returns Output only. Assessment of this transaction for behavioral trust.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 961 class FraudPreventionAssessment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. # @!attribute [r] reason # @return [::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason] # Output only. Risk reasons applicable to the Fraud Prevention assessment. class RiskReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. New risk # reasons will be added over time. module Reason # Default unspecified type. REASON_UNSPECIFIED = 0 # A suspiciously high number of recent transactions have used identifiers # present in this transaction. HIGH_TRANSACTION_VELOCITY = 1 # User is cycling through a suspiciously large number of identifiers, # suggesting enumeration or validation attacks within a potential fraud # network. EXCESSIVE_ENUMERATION_PATTERN = 2 # User has a short history or no history in the reCAPTCHA network, # suggesting the possibility of synthetic identity generation. SHORT_IDENTITY_HISTORY = 3 # Identifiers used in this transaction originate from an unusual or # conflicting set of geolocations. GEOLOCATION_DISCREPANCY = 4 # This transaction is linked to a cluster of known fraudulent activity. ASSOCIATED_WITH_FRAUD_CLUSTER = 5 end end # Information about stolen instrument fraud, where the user is not the # legitimate owner of the instrument being used for the purchase. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction being executed with a stolen # instrument. Values are from 0.0 (lowest) to 1.0 (highest). class StolenInstrumentVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about card testing fraud, where an adversary is testing # fraudulently obtained cards or brute forcing their details. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction attempt being part of a card # testing attack. Values are from 0.0 (lowest) to 1.0 (highest). class CardTestingVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about behavioral trust of the transaction. # @!attribute [r] trust # @return [::Float] # Output only. Probability of this transaction attempt being executed in a # behaviorally trustworthy way. Values are from 0.0 (lowest) to 1.0 # (highest). class BehavioralTrustVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#card_testing_verdict ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::CardTestingVerdict (readonly)
Returns Output only. Assessment of this transaction for risk of being part of a card testing attack.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 961 class FraudPreventionAssessment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. # @!attribute [r] reason # @return [::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason] # Output only. Risk reasons applicable to the Fraud Prevention assessment. class RiskReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. New risk # reasons will be added over time. module Reason # Default unspecified type. REASON_UNSPECIFIED = 0 # A suspiciously high number of recent transactions have used identifiers # present in this transaction. HIGH_TRANSACTION_VELOCITY = 1 # User is cycling through a suspiciously large number of identifiers, # suggesting enumeration or validation attacks within a potential fraud # network. EXCESSIVE_ENUMERATION_PATTERN = 2 # User has a short history or no history in the reCAPTCHA network, # suggesting the possibility of synthetic identity generation. SHORT_IDENTITY_HISTORY = 3 # Identifiers used in this transaction originate from an unusual or # conflicting set of geolocations. GEOLOCATION_DISCREPANCY = 4 # This transaction is linked to a cluster of known fraudulent activity. ASSOCIATED_WITH_FRAUD_CLUSTER = 5 end end # Information about stolen instrument fraud, where the user is not the # legitimate owner of the instrument being used for the purchase. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction being executed with a stolen # instrument. Values are from 0.0 (lowest) to 1.0 (highest). class StolenInstrumentVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about card testing fraud, where an adversary is testing # fraudulently obtained cards or brute forcing their details. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction attempt being part of a card # testing attack. Values are from 0.0 (lowest) to 1.0 (highest). class CardTestingVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about behavioral trust of the transaction. # @!attribute [r] trust # @return [::Float] # Output only. Probability of this transaction attempt being executed in a # behaviorally trustworthy way. Values are from 0.0 (lowest) to 1.0 # (highest). class BehavioralTrustVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#risk_reasons ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason> (readonly)
Returns Output only. Reasons why the transaction is probably fraudulent and received a high transaction risk score.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 961 class FraudPreventionAssessment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. # @!attribute [r] reason # @return [::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason] # Output only. Risk reasons applicable to the Fraud Prevention assessment. class RiskReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. New risk # reasons will be added over time. module Reason # Default unspecified type. REASON_UNSPECIFIED = 0 # A suspiciously high number of recent transactions have used identifiers # present in this transaction. HIGH_TRANSACTION_VELOCITY = 1 # User is cycling through a suspiciously large number of identifiers, # suggesting enumeration or validation attacks within a potential fraud # network. EXCESSIVE_ENUMERATION_PATTERN = 2 # User has a short history or no history in the reCAPTCHA network, # suggesting the possibility of synthetic identity generation. SHORT_IDENTITY_HISTORY = 3 # Identifiers used in this transaction originate from an unusual or # conflicting set of geolocations. GEOLOCATION_DISCREPANCY = 4 # This transaction is linked to a cluster of known fraudulent activity. ASSOCIATED_WITH_FRAUD_CLUSTER = 5 end end # Information about stolen instrument fraud, where the user is not the # legitimate owner of the instrument being used for the purchase. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction being executed with a stolen # instrument. Values are from 0.0 (lowest) to 1.0 (highest). class StolenInstrumentVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about card testing fraud, where an adversary is testing # fraudulently obtained cards or brute forcing their details. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction attempt being part of a card # testing attack. Values are from 0.0 (lowest) to 1.0 (highest). class CardTestingVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about behavioral trust of the transaction. # @!attribute [r] trust # @return [::Float] # Output only. Probability of this transaction attempt being executed in a # behaviorally trustworthy way. Values are from 0.0 (lowest) to 1.0 # (highest). class BehavioralTrustVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#stolen_instrument_verdict ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::StolenInstrumentVerdict (readonly)
Returns Output only. Assessment of this transaction for risk of a stolen instrument.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 961 class FraudPreventionAssessment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. # @!attribute [r] reason # @return [::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason] # Output only. Risk reasons applicable to the Fraud Prevention assessment. class RiskReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. New risk # reasons will be added over time. module Reason # Default unspecified type. REASON_UNSPECIFIED = 0 # A suspiciously high number of recent transactions have used identifiers # present in this transaction. HIGH_TRANSACTION_VELOCITY = 1 # User is cycling through a suspiciously large number of identifiers, # suggesting enumeration or validation attacks within a potential fraud # network. EXCESSIVE_ENUMERATION_PATTERN = 2 # User has a short history or no history in the reCAPTCHA network, # suggesting the possibility of synthetic identity generation. SHORT_IDENTITY_HISTORY = 3 # Identifiers used in this transaction originate from an unusual or # conflicting set of geolocations. GEOLOCATION_DISCREPANCY = 4 # This transaction is linked to a cluster of known fraudulent activity. ASSOCIATED_WITH_FRAUD_CLUSTER = 5 end end # Information about stolen instrument fraud, where the user is not the # legitimate owner of the instrument being used for the purchase. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction being executed with a stolen # instrument. Values are from 0.0 (lowest) to 1.0 (highest). class StolenInstrumentVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about card testing fraud, where an adversary is testing # fraudulently obtained cards or brute forcing their details. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction attempt being part of a card # testing attack. Values are from 0.0 (lowest) to 1.0 (highest). class CardTestingVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about behavioral trust of the transaction. # @!attribute [r] trust # @return [::Float] # Output only. Probability of this transaction attempt being executed in a # behaviorally trustworthy way. Values are from 0.0 (lowest) to 1.0 # (highest). class BehavioralTrustVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#transaction_risk ⇒ ::Float (readonly)
Returns Output only. Probability of this transaction being fraudulent. Summarizes the combined risk of attack vectors below. Values are from 0.0 (lowest) to 1.0 (highest).
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 961 class FraudPreventionAssessment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. # @!attribute [r] reason # @return [::Google::Cloud::RecaptchaEnterprise::V1::FraudPreventionAssessment::RiskReason::Reason] # Output only. Risk reasons applicable to the Fraud Prevention assessment. class RiskReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Risk reasons applicable to the Fraud Prevention assessment. New risk # reasons will be added over time. module Reason # Default unspecified type. REASON_UNSPECIFIED = 0 # A suspiciously high number of recent transactions have used identifiers # present in this transaction. HIGH_TRANSACTION_VELOCITY = 1 # User is cycling through a suspiciously large number of identifiers, # suggesting enumeration or validation attacks within a potential fraud # network. EXCESSIVE_ENUMERATION_PATTERN = 2 # User has a short history or no history in the reCAPTCHA network, # suggesting the possibility of synthetic identity generation. SHORT_IDENTITY_HISTORY = 3 # Identifiers used in this transaction originate from an unusual or # conflicting set of geolocations. GEOLOCATION_DISCREPANCY = 4 # This transaction is linked to a cluster of known fraudulent activity. ASSOCIATED_WITH_FRAUD_CLUSTER = 5 end end # Information about stolen instrument fraud, where the user is not the # legitimate owner of the instrument being used for the purchase. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction being executed with a stolen # instrument. Values are from 0.0 (lowest) to 1.0 (highest). class StolenInstrumentVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about card testing fraud, where an adversary is testing # fraudulently obtained cards or brute forcing their details. # @!attribute [r] risk # @return [::Float] # Output only. Probability of this transaction attempt being part of a card # testing attack. Values are from 0.0 (lowest) to 1.0 (highest). class CardTestingVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Information about behavioral trust of the transaction. # @!attribute [r] trust # @return [::Float] # Output only. Probability of this transaction attempt being executed in a # behaviorally trustworthy way. Values are from 0.0 (lowest) to 1.0 # (highest). class BehavioralTrustVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |