Class: Google::Cloud::RecaptchaEnterprise::V1::SmsTollFraudVerdict
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::SmsTollFraudVerdict
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Information about SMS toll fraud.
Defined Under Namespace
Modules: SmsTollFraudReason
Instance Attribute Summary collapse
-
#reasons ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::SmsTollFraudVerdict::SmsTollFraudReason>
readonly
Output only.
-
#risk ⇒ ::Float
readonly
Output only.
Instance Attribute Details
#reasons ⇒ ::Array<::Google::Cloud::RecaptchaEnterprise::V1::SmsTollFraudVerdict::SmsTollFraudReason> (readonly)
Returns Output only. Reasons contributing to the SMS toll fraud verdict.
1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1099 class SmsTollFraudVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Reasons contributing to the SMS toll fraud verdict. # Ensure that applications can handle values not explicitly listed. module SmsTollFraudReason # Default unspecified reason SMS_TOLL_FRAUD_REASON_UNSPECIFIED = 0 # The provided phone number was invalid INVALID_PHONE_NUMBER = 1 end end |
#risk ⇒ ::Float (readonly)
Returns Output only. Probability of an SMS event being fraudulent. Values are from 0.0 (lowest) to 1.0 (highest).
1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1099 class SmsTollFraudVerdict include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Reasons contributing to the SMS toll fraud verdict. # Ensure that applications can handle values not explicitly listed. module SmsTollFraudReason # Default unspecified reason SMS_TOLL_FRAUD_REASON_UNSPECIFIED = 0 # The provided phone number was invalid INVALID_PHONE_NUMBER = 1 end end |