Class: Google::Cloud::RecaptchaEnterprise::V1::TokenProperties
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::TokenProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Properties of the provided event token.
Defined Under Namespace
Modules: InvalidReason
Instance Attribute Summary collapse
-
#action ⇒ ::String
readonly
Output only.
-
#android_package_name ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#hostname ⇒ ::String
readonly
Output only.
-
#invalid_reason ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::TokenProperties::InvalidReason
readonly
Output only.
-
#ios_bundle_id ⇒ ::String
readonly
Output only.
-
#valid ⇒ ::Boolean
readonly
Output only.
Instance Attribute Details
#action ⇒ ::String (readonly)
Returns Output only. Action name provided at token generation.
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |
#android_package_name ⇒ ::String (readonly)
Returns Output only. The name of the Android package with which the token was generated (Android keys only).
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp corresponding to the generation of the token.
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |
#hostname ⇒ ::String (readonly)
Returns Output only. The hostname of the page on which the token was generated (Web keys only).
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |
#invalid_reason ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::TokenProperties::InvalidReason (readonly)
Returns Output only. Reason associated with the response when valid = false.
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |
#ios_bundle_id ⇒ ::String (readonly)
Returns Output only. The ID of the iOS bundle with which the token was generated (iOS keys only).
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |
#valid ⇒ ::Boolean (readonly)
Returns Output only. Whether the provided user response token is valid. When valid = false, the reason could be specified in invalid_reason or it could also be due to a user failing to solve a challenge or a sitekey mismatch (i.e the sitekey used to generate the token was different than the one specified in the assessment).
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 899 class TokenProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum that represents the types of invalid token reasons. # Ensure that applications can handle values not explicitly listed. module InvalidReason # Default unspecified type. INVALID_REASON_UNSPECIFIED = 0 # If the failure reason was not accounted for. UNKNOWN_INVALID_REASON = 1 # The provided user verification token was malformed. MALFORMED = 2 # The user verification token had expired. EXPIRED = 3 # The user verification had already been seen. DUPE = 4 # The user verification token was not present. MISSING = 5 # A retriable error (such as network failure) occurred on the browser. # Could easily be simulated by an attacker. BROWSER_ERROR = 6 # The action provided at token generation was different than # the `expected_action` in the assessment request. The comparison is # case-insensitive. This reason can only be returned if all of the # following are true: # # - your `site_key` has the POLICY_BASED_CHALLENGE integration type # - you set an action score threshold higher than 0.0 # - you provided a non-empty `expected_action` UNEXPECTED_ACTION = 7 end end |