Class: Google::Cloud::RecaptchaEnterprise::V1::WafSettings
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::WafSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Settings specific to keys that can be used for WAF (Web Application Firewall).
Defined Under Namespace
Modules: WafFeature, WafService
Instance Attribute Summary collapse
-
#waf_feature ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WafSettings::WafFeature
Required.
-
#waf_service ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WafSettings::WafService
Required.
Instance Attribute Details
#waf_feature ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WafSettings::WafFeature
Returns Required. The Web Application Firewall (WAF) feature for which this key is enabled.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 2135 class WafSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported WAF features. For more information, see # https://cloud.google.com/recaptcha/docs/usecase#comparison_of_features. # Ensure that applications can handle values not explicitly listed. module WafFeature # Undefined feature. WAF_FEATURE_UNSPECIFIED = 0 # Redirects suspicious traffic to reCAPTCHA. CHALLENGE_PAGE = 1 # Use reCAPTCHA session-tokens to protect the whole user session on the # site's domain. SESSION_TOKEN = 2 # Use reCAPTCHA action-tokens to protect user actions. ACTION_TOKEN = 3 # Deprecated: Use `express_settings` instead. EXPRESS = 5 end # Web Application Firewalls that reCAPTCHA supports. # Ensure that applications can handle values not explicitly listed. module WafService # Undefined WAF WAF_SERVICE_UNSPECIFIED = 0 # Cloud Armor CA = 1 # Fastly FASTLY = 3 # Cloudflare CLOUDFLARE = 4 # Akamai AKAMAI = 5 end end |
#waf_service ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WafSettings::WafService
Returns Required. The Web Application Firewall (WAF) service that uses this key.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 2135 class WafSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported WAF features. For more information, see # https://cloud.google.com/recaptcha/docs/usecase#comparison_of_features. # Ensure that applications can handle values not explicitly listed. module WafFeature # Undefined feature. WAF_FEATURE_UNSPECIFIED = 0 # Redirects suspicious traffic to reCAPTCHA. CHALLENGE_PAGE = 1 # Use reCAPTCHA session-tokens to protect the whole user session on the # site's domain. SESSION_TOKEN = 2 # Use reCAPTCHA action-tokens to protect user actions. ACTION_TOKEN = 3 # Deprecated: Use `express_settings` instead. EXPRESS = 5 end # Web Application Firewalls that reCAPTCHA supports. # Ensure that applications can handle values not explicitly listed. module WafService # Undefined WAF WAF_SERVICE_UNSPECIFIED = 0 # Cloud Armor CA = 1 # Fastly FASTLY = 3 # Cloudflare CLOUDFLARE = 4 # Akamai AKAMAI = 5 end end |