Class: Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings
- Inherits:
-
Object
- Object
- Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb
Overview
Settings specific to keys that can be used by websites.
Defined Under Namespace
Modules: ChallengeSecurityPreference, IntegrationType Classes: ActionSettings, ChallengeSettings
Instance Attribute Summary collapse
-
#allow_all_domains ⇒ ::Boolean
Optional.
-
#allow_amp_traffic ⇒ ::Boolean
Optional.
-
#allowed_domains ⇒ ::Array<::String>
Optional.
-
#challenge_security_preference ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ChallengeSecurityPreference
Optional.
-
#challenge_settings ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ChallengeSettings
Optional.
-
#integration_type ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::IntegrationType
Required.
Instance Attribute Details
#allow_all_domains ⇒ ::Boolean
Returns Optional. If set to true, it means allowed_domains are not enforced.
1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1522 class WebKeySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Per-action challenge settings. # @!attribute [rw] score_threshold # @return [::Float] # Required. A challenge is triggered if the end-user score is below that # threshold. Value must be between 0 and 1 (inclusive). class ActionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is # triggered. # @!attribute [rw] default_settings # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] # Required. Defines when a challenge is triggered (unless the default # threshold is overridden for the given action, see `action_settings`). # @!attribute [rw] action_settings # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}] # Optional. The action to score threshold map. # The action name should be the same as the action name passed in the # `data-action` attribute # (see https://cloud.google.com/recaptcha/docs/actions-website). # Action names are case-insensitive. # There is a maximum of 100 action settings. # An action name has a maximum length of 100. class ChallengeSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] class ActionSettingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Enum that represents the integration types for web keys. # Ensure that applications can handle values not explicitly listed. module IntegrationType # Default type that indicates this enum hasn't been specified. This is not # a valid IntegrationType, one of the other types must be specified # instead. INTEGRATION_TYPE_UNSPECIFIED = 0 # Only used to produce scores. It doesn't display the "I'm not a robot" # checkbox and never shows captcha challenges. SCORE = 1 # Displays the "I'm not a robot" checkbox and may show captcha challenges # after it is checked. CHECKBOX = 2 # Doesn't display the "I'm not a robot" checkbox, but may show captcha # challenges after risk analysis. INVISIBLE = 3 # Displays a visual challenge or not depending on the user risk analysis # score. POLICY_BASED_CHALLENGE = 5 end # Enum that represents the possible challenge frequency and difficulty # configurations for a web key. # Ensure that applications can handle values not explicitly listed. module ChallengeSecurityPreference # Default type that indicates this enum hasn't been specified. CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED = 0 # Key tends to show fewer and easier challenges. USABILITY = 1 # Key tends to show balanced (in amount and difficulty) challenges. BALANCE = 2 # Key tends to show more and harder challenges. SECURITY = 3 end end |
#allow_amp_traffic ⇒ ::Boolean
Returns Optional. If set to true, the key can be used on AMP (Accelerated Mobile Pages) websites. This is supported only for the SCORE integration type.
1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1522 class WebKeySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Per-action challenge settings. # @!attribute [rw] score_threshold # @return [::Float] # Required. A challenge is triggered if the end-user score is below that # threshold. Value must be between 0 and 1 (inclusive). class ActionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is # triggered. # @!attribute [rw] default_settings # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] # Required. Defines when a challenge is triggered (unless the default # threshold is overridden for the given action, see `action_settings`). # @!attribute [rw] action_settings # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}] # Optional. The action to score threshold map. # The action name should be the same as the action name passed in the # `data-action` attribute # (see https://cloud.google.com/recaptcha/docs/actions-website). # Action names are case-insensitive. # There is a maximum of 100 action settings. # An action name has a maximum length of 100. class ChallengeSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] class ActionSettingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Enum that represents the integration types for web keys. # Ensure that applications can handle values not explicitly listed. module IntegrationType # Default type that indicates this enum hasn't been specified. This is not # a valid IntegrationType, one of the other types must be specified # instead. INTEGRATION_TYPE_UNSPECIFIED = 0 # Only used to produce scores. It doesn't display the "I'm not a robot" # checkbox and never shows captcha challenges. SCORE = 1 # Displays the "I'm not a robot" checkbox and may show captcha challenges # after it is checked. CHECKBOX = 2 # Doesn't display the "I'm not a robot" checkbox, but may show captcha # challenges after risk analysis. INVISIBLE = 3 # Displays a visual challenge or not depending on the user risk analysis # score. POLICY_BASED_CHALLENGE = 5 end # Enum that represents the possible challenge frequency and difficulty # configurations for a web key. # Ensure that applications can handle values not explicitly listed. module ChallengeSecurityPreference # Default type that indicates this enum hasn't been specified. CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED = 0 # Key tends to show fewer and easier challenges. USABILITY = 1 # Key tends to show balanced (in amount and difficulty) challenges. BALANCE = 2 # Key tends to show more and harder challenges. SECURITY = 3 end end |
#allowed_domains ⇒ ::Array<::String>
Returns Optional. Domains or subdomains of websites allowed to use the key. All
subdomains of an allowed domain are automatically allowed. A valid domain
requires a host and must not include any path, port, query or fragment.
Examples: 'example.com' or 'subdomain.example.com'
Each key supports a maximum of 250 domains. To use a key on more domains,
set allow_all_domains to true. When this is set, you are responsible for
validating the hostname by checking the token_properties.hostname field
in each assessment response against your list of allowed domains.
1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1522 class WebKeySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Per-action challenge settings. # @!attribute [rw] score_threshold # @return [::Float] # Required. A challenge is triggered if the end-user score is below that # threshold. Value must be between 0 and 1 (inclusive). class ActionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is # triggered. # @!attribute [rw] default_settings # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] # Required. Defines when a challenge is triggered (unless the default # threshold is overridden for the given action, see `action_settings`). # @!attribute [rw] action_settings # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}] # Optional. The action to score threshold map. # The action name should be the same as the action name passed in the # `data-action` attribute # (see https://cloud.google.com/recaptcha/docs/actions-website). # Action names are case-insensitive. # There is a maximum of 100 action settings. # An action name has a maximum length of 100. class ChallengeSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] class ActionSettingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Enum that represents the integration types for web keys. # Ensure that applications can handle values not explicitly listed. module IntegrationType # Default type that indicates this enum hasn't been specified. This is not # a valid IntegrationType, one of the other types must be specified # instead. INTEGRATION_TYPE_UNSPECIFIED = 0 # Only used to produce scores. It doesn't display the "I'm not a robot" # checkbox and never shows captcha challenges. SCORE = 1 # Displays the "I'm not a robot" checkbox and may show captcha challenges # after it is checked. CHECKBOX = 2 # Doesn't display the "I'm not a robot" checkbox, but may show captcha # challenges after risk analysis. INVISIBLE = 3 # Displays a visual challenge or not depending on the user risk analysis # score. POLICY_BASED_CHALLENGE = 5 end # Enum that represents the possible challenge frequency and difficulty # configurations for a web key. # Ensure that applications can handle values not explicitly listed. module ChallengeSecurityPreference # Default type that indicates this enum hasn't been specified. CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED = 0 # Key tends to show fewer and easier challenges. USABILITY = 1 # Key tends to show balanced (in amount and difficulty) challenges. BALANCE = 2 # Key tends to show more and harder challenges. SECURITY = 3 end end |
#challenge_security_preference ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ChallengeSecurityPreference
Returns Optional. Settings for the frequency and difficulty at which this key
triggers captcha challenges. This should only be specified for
IntegrationType CHECKBOX, INVISIBLE or POLICY_BASED_CHALLENGE.
1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1522 class WebKeySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Per-action challenge settings. # @!attribute [rw] score_threshold # @return [::Float] # Required. A challenge is triggered if the end-user score is below that # threshold. Value must be between 0 and 1 (inclusive). class ActionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is # triggered. # @!attribute [rw] default_settings # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] # Required. Defines when a challenge is triggered (unless the default # threshold is overridden for the given action, see `action_settings`). # @!attribute [rw] action_settings # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}] # Optional. The action to score threshold map. # The action name should be the same as the action name passed in the # `data-action` attribute # (see https://cloud.google.com/recaptcha/docs/actions-website). # Action names are case-insensitive. # There is a maximum of 100 action settings. # An action name has a maximum length of 100. class ChallengeSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] class ActionSettingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Enum that represents the integration types for web keys. # Ensure that applications can handle values not explicitly listed. module IntegrationType # Default type that indicates this enum hasn't been specified. This is not # a valid IntegrationType, one of the other types must be specified # instead. INTEGRATION_TYPE_UNSPECIFIED = 0 # Only used to produce scores. It doesn't display the "I'm not a robot" # checkbox and never shows captcha challenges. SCORE = 1 # Displays the "I'm not a robot" checkbox and may show captcha challenges # after it is checked. CHECKBOX = 2 # Doesn't display the "I'm not a robot" checkbox, but may show captcha # challenges after risk analysis. INVISIBLE = 3 # Displays a visual challenge or not depending on the user risk analysis # score. POLICY_BASED_CHALLENGE = 5 end # Enum that represents the possible challenge frequency and difficulty # configurations for a web key. # Ensure that applications can handle values not explicitly listed. module ChallengeSecurityPreference # Default type that indicates this enum hasn't been specified. CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED = 0 # Key tends to show fewer and easier challenges. USABILITY = 1 # Key tends to show balanced (in amount and difficulty) challenges. BALANCE = 2 # Key tends to show more and harder challenges. SECURITY = 3 end end |
#challenge_settings ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ChallengeSettings
Returns Optional. Challenge settings.
1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1522 class WebKeySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Per-action challenge settings. # @!attribute [rw] score_threshold # @return [::Float] # Required. A challenge is triggered if the end-user score is below that # threshold. Value must be between 0 and 1 (inclusive). class ActionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is # triggered. # @!attribute [rw] default_settings # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] # Required. Defines when a challenge is triggered (unless the default # threshold is overridden for the given action, see `action_settings`). # @!attribute [rw] action_settings # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}] # Optional. The action to score threshold map. # The action name should be the same as the action name passed in the # `data-action` attribute # (see https://cloud.google.com/recaptcha/docs/actions-website). # Action names are case-insensitive. # There is a maximum of 100 action settings. # An action name has a maximum length of 100. class ChallengeSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] class ActionSettingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Enum that represents the integration types for web keys. # Ensure that applications can handle values not explicitly listed. module IntegrationType # Default type that indicates this enum hasn't been specified. This is not # a valid IntegrationType, one of the other types must be specified # instead. INTEGRATION_TYPE_UNSPECIFIED = 0 # Only used to produce scores. It doesn't display the "I'm not a robot" # checkbox and never shows captcha challenges. SCORE = 1 # Displays the "I'm not a robot" checkbox and may show captcha challenges # after it is checked. CHECKBOX = 2 # Doesn't display the "I'm not a robot" checkbox, but may show captcha # challenges after risk analysis. INVISIBLE = 3 # Displays a visual challenge or not depending on the user risk analysis # score. POLICY_BASED_CHALLENGE = 5 end # Enum that represents the possible challenge frequency and difficulty # configurations for a web key. # Ensure that applications can handle values not explicitly listed. module ChallengeSecurityPreference # Default type that indicates this enum hasn't been specified. CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED = 0 # Key tends to show fewer and easier challenges. USABILITY = 1 # Key tends to show balanced (in amount and difficulty) challenges. BALANCE = 2 # Key tends to show more and harder challenges. SECURITY = 3 end end |
#integration_type ⇒ ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::IntegrationType
Returns Required. Describes how this key is integrated with the website.
1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/recaptchaenterprise/v1/recaptchaenterprise.rb', line 1522 class WebKeySettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Per-action challenge settings. # @!attribute [rw] score_threshold # @return [::Float] # Required. A challenge is triggered if the end-user score is below that # threshold. Value must be between 0 and 1 (inclusive). class ActionSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is # triggered. # @!attribute [rw] default_settings # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] # Required. Defines when a challenge is triggered (unless the default # threshold is overridden for the given action, see `action_settings`). # @!attribute [rw] action_settings # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings}] # Optional. The action to score threshold map. # The action name should be the same as the action name passed in the # `data-action` attribute # (see https://cloud.google.com/recaptcha/docs/actions-website). # Action names are case-insensitive. # There is a maximum of 100 action settings. # An action name has a maximum length of 100. class ChallengeSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::RecaptchaEnterprise::V1::WebKeySettings::ActionSettings] class ActionSettingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Enum that represents the integration types for web keys. # Ensure that applications can handle values not explicitly listed. module IntegrationType # Default type that indicates this enum hasn't been specified. This is not # a valid IntegrationType, one of the other types must be specified # instead. INTEGRATION_TYPE_UNSPECIFIED = 0 # Only used to produce scores. It doesn't display the "I'm not a robot" # checkbox and never shows captcha challenges. SCORE = 1 # Displays the "I'm not a robot" checkbox and may show captcha challenges # after it is checked. CHECKBOX = 2 # Doesn't display the "I'm not a robot" checkbox, but may show captcha # challenges after risk analysis. INVISIBLE = 3 # Displays a visual challenge or not depending on the user risk analysis # score. POLICY_BASED_CHALLENGE = 5 end # Enum that represents the possible challenge frequency and difficulty # configurations for a web key. # Ensure that applications can handle values not explicitly listed. module ChallengeSecurityPreference # Default type that indicates this enum hasn't been specified. CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED = 0 # Key tends to show fewer and easier challenges. USABILITY = 1 # Key tends to show balanced (in amount and difficulty) challenges. BALANCE = 2 # Key tends to show more and harder challenges. SECURITY = 3 end end |